%% fig2_mean_learningcurves
% plot the mean + SEM of the learning curves
%
% Niek Beckers, 2020
clearvars; close all; clc;

tikz_path = 'img/tikz-src/';
mkdir(tikz_path);

figsize = [0 0 700 400];

load('../data/data_rmse_all.mat')

%% solo and int int group
% colors and stuff
clr_solo_single = [245,125,0]/255;
clr_int_single = [  1, 99,153]/255;
clr_stiffconn_single = [  166,97,26]/255;
clr_contint_single  = [25,110,37]/255;

% to mm
ydata_int_single = ydata_int_single*1e3; % to cm
ydata_int_conn = ydata_int_conn*1e3; % to cm
ydata_solo_single = ydata_solo_single*1e3; % to cm
ydata_stiffconn_single = ydata_stiffconn_single*1e3;
ydata_int_single_contint = ydata_int_single_contint*1e3;

% plot all together
figure('color','w','position',figsize);

%% solo_single
% block 1
errorbar(nanmean(xdata_solo_single(1:21,:),2),nanmean(ydata_solo_single(1:21,:),2), nanstd(ydata_solo_single(1:21,:),[],2)/sqrt(size(ydata_solo_single(1:21,:),2)),'o-','color',clr_solo_single,'markerfacecolor',clr_solo_single); hold on
% block 2,3,4
he(1) = errorbar(nanmean(xdata_solo_single(22:end,:),2),nanmean(ydata_solo_single(22:end,:),2), nanstd(ydata_solo_single(22:end,:),[],2)/sqrt(size(ydata_solo_single(22:end,:),2)),'o-','color',clr_solo_single,'markerfacecolor',clr_solo_single);

%% int_single
% block 1
errorbar(nanmean(xdata_int_single(1:11,:),2),nanmean(ydata_int_single(1:11,:),2), nanstd(ydata_int_single(1:11,:),[],2)/sqrt(size(ydata_int_single(1:11,:),2)),'s-','color',clr_int_single,'markerfacecolor',clr_int_single); hold on;
% block 2,3,4
he(2) = errorbar(nanmean(xdata_int_single(12:44,:),2),nanmean(ydata_int_single(12:44,:),2), nanstd(ydata_int_single(12:44,:),[],2)/sqrt(size(ydata_int_single(12:44,:),2)),'s-','color',clr_int_single,'markerfacecolor',clr_int_single);

%% stiff int group
% block 1
errorbar(nanmean(xdata_stiffconn_single(1:21,:),2),nanmean(ydata_stiffconn_single(1:21,:),2), nanstd(ydata_stiffconn_single(1:21,:),[],2)/sqrt(size(ydata_stiffconn_single(1:21,:),2)),'^-','color',clr_stiffconn_single,'markerfacecolor',clr_stiffconn_single); hold on;
% block 2,3,4
he(3) = errorbar(nanmean(xdata_stiffconn_single(22:84,:),2),nanmean(ydata_stiffconn_single(22:84,:),2), nanstd(ydata_stiffconn_single(22:84,:),[],2)/sqrt(size(ydata_stiffconn_single(22:84,:),2)),'^-','color',clr_stiffconn_single,'markerfacecolor',clr_stiffconn_single);

%% cont int group
% remove participant 11 (see paper)
ydata_int_single_contint(:,11) = NaN;

% first, plot trial 13 only
errorbar(nanmean(xdata_int_single_contint(13,:),2),nanmean(ydata_int_single_contint(13,:),2), nanstd(ydata_int_single_contint(13,:),[],2)/sqrt(size(ydata_int_single_contint(13,:),2)),'>-','color',clr_contint_single,'markerfacecolor',clr_contint_single); hold on;
ydata_int_single_contint(13,:) = NaN;

errorbar(nanmean(xdata_int_single_contint(1:21,:),2),nanmean(ydata_int_single_contint(1:21,:),2), nanstd(ydata_int_single_contint(1:21,:),[],2)/sqrt(size(ydata_int_single_contint(1:21,:),2)),'>-','color',clr_contint_single,'markerfacecolor',clr_contint_single); hold on;
% block 2,3,4
he(4) = errorbar(nanmean(xdata_int_single_contint(22:84,:),2),nanmean(ydata_int_single_contint(22:84,:),2), nanstd(ydata_int_single_contint(22:84,:),[],2)/sqrt(size(ydata_int_single_contint(22:84,:),2)),'>-','color',clr_contint_single,'markerfacecolor',clr_contint_single);

%% layout
vylim = [0 60];
hp = plot([21.5 21.5],vylim,'k-'); uistack(hp,'bottom')
box on;
xlabel('Trial, -','interpreter','latex'); ylabel('$E$ [cm]','interpreter','latex');
set(gca,'XLim',[0 85],'YLim',vylim);

set(get(gcf,'children'),'fontsize',14);
legend(he,{'Solo, single','Interaction, single','Stiff int., single','Cont. int., single'},'fontsize',10);