%% fig3_group_comparison
% Scientific Reports paper
% Niek Beckers
clearvars; close all; clc;


clr_solo_single      = [245,10,0]/255;
clr_int_single       = [  1, 99,153]/255;
clr_int_conn         = [4,194,31]/255;
clr_contint_single   = [25,110,37]/255;
clr_contint_conn     = [ 85,161,202]/255;
clr_stiffconn_single = [  166,97,26]/255;
clr_stiffconn_conn   = [ 223,194,125]/255;

% load data
load('../data/data_rmse_all.mat');

% participant 11, cont int group
ydata_int_single_contint(:,11) = NaN;

%% calculate final tracking error

% indices to select correct trials
idx_Ef_single1 = [76 78 80 82 84];
idx_Ef_single2 = [40 41 42 43 44];

% int and solo
Ef_solo_single  = nanmean(ydata_solo_single(idx_Ef_single1,:),1).';
Ef_int_single = nanmean(ydata_int_single(idx_Ef_single2,:),1).';

% stiffconn 
Ef_stiffconn_single = nanmean(ydata_stiffconn_single(idx_Ef_single1,:),1).';
% cont int
Ef_contint_single = nanmean(ydata_int_single_contint(idx_Ef_single1,:),1).';

%% E0 (initial performance)
E0_solo_single  = ydata_solo_single(22,:).';
E0_int_single = ydata_int_single(12,:).'; % odd one out
E0_stiffconn_single = ydata_stiffconn_single(22,:).';
E0_contint_single = ydata_int_single_contint(13,:).';

%% improvement
imp_solo_single = E0_solo_single-Ef_solo_single;
imp_int_single = E0_int_single-Ef_int_single;
imp_stiffconn_single = E0_stiffconn_single-Ef_stiffconn_single;
imp_contint_single = E0_contint_single-Ef_contint_single;

%% plot improvement

% combine data
y = padcat(imp_solo_single,imp_int_single,imp_stiffconn_single,imp_contint_single)*1e3;
ym = nanmean(y,1);
ye = nanstd(y,[],1)/sqrt(size(y,1));

figure('color','w')

hbp = bar([1 2 3 4], ym); hold on;
plot(1*ones(size(y(:,1))),y(:,1),'o','color',clr_solo_single,'markerfacecolor',clr_solo_single);
plot(2*ones(size(y(:,2))),y(:,2),'s','color',clr_int_single,'markerfacecolor',clr_int_single);
plot(3*ones(size(y(:,4))),y(:,4),'^','color',clr_stiffconn_single,'markerfacecolor',clr_stiffconn_single);
plot(4*ones(size(y(:,3))),y(:,3),'>','color',clr_contint_single,'markerfacecolor',clr_contint_single);
errorbar([1 2 3 4],ym,ye,'linestyle','none','color','k','linewidth',2)

% layout
hbp.FaceColor = 'flat';
hbp.FaceAlpha = 0.4;
hbp.CData(1,:) = clr_solo_single;
hbp.CData(2,:) = clr_int_single;
hbp.CData(3,:) = clr_stiffconn_single;
hbp.CData(4,:) = clr_contint_single;

ylabel('Improvement, mm','interpreter','latex');
ylim([0 70]);
set(gca,'XTickLabel',{'solo','int. int.','stiff conn.','cont. int.'})

% matlab2tikz
% tikz_path = 'img/tikz-src/';
% matlab2tikz([tikz_path 'improvement-grouplevel.tex'],'externaldata',true,'dataPath',[tikz_path 'data-improvement-grouplevel']); % ,'extraCode','\tikzsetnextfilename{\currfilebase}'

%% plot improvement rates
load('../data/data_improvement_rates.mat');

figure('color','w')

subplot(121);
y_slow = padcat(fit_solo_single_ind_2exp.p(5,:).', fit_int_single_ind_2exp.p(5,:).', fit_stiffconn_single_ind_2exp.p(5,:).');

hbp = boxplot(y_slow); hold on;
% color the boxplots
hb = findobj(hbp(:,1),'Type','Line'); set(hb,'color',clr_solo_single);
hb = findobj(hbp(:,2),'Type','Line'); set(hb,'color',clr_int_single);
hb = findobj(hbp(:,3),'Type','Line'); set(hb,'color',clr_stiffconn_single);
hb = findobj(hbp,'Tag','Box');
set(hb(1),'Color',clr_solo_single,'LineWidth',2);
set(hb(2),'Color',clr_int_single,'LineWidth',2);
set(hb(3),'Color',clr_stiffconn_single,'LineWidth',2);
ylabel('slow improvement rate')
ylim([0 0.5])

% fast improvement rate
subplot(122);
y_fast = padcat(fit_solo_single_ind_2exp.p(3,:).', fit_int_single_ind_2exp.p(3,:).', fit_stiffconn_single_ind_2exp.p(3,:).');

hbp = boxplot(y_fast); hold on;
% color the boxplots
hb = findobj(hbp(:,1),'Type','Line'); set(hb,'color',clr_solo_single);
hb = findobj(hbp(:,2),'Type','Line'); set(hb,'color',clr_int_single);
hb = findobj(hbp(:,3),'Type','Line'); set(hb,'color',clr_stiffconn_single);
hb = findobj(hbp,'Tag','Box');
set(hb(1),'Color',clr_solo_single,'LineWidth',2);
set(hb(2),'Color',clr_int_single,'LineWidth',2);
set(hb(3),'Color',clr_stiffconn_single,'LineWidth',2);
ylabel('fast improvement rate');
ylim([0 6])

%% tracking error increase introduction of visuomotor rotation
Ebl = [ydata_solo_single(21,:).' ydata_int_single(11,:).' ydata_stiffconn_single(21,:).' ydata_int_single_contint(12,:).'];
delta_error_initial = Ebl - [E0_solo_single E0_int_single E0_stiffconn_single E0_contint_single];

