%% fig4_Es0_improvement_rates
% Paper figures 
% Niek Beckers, 2020

clearvars; 
close all; clc;

tikz_path = 'img/tikz-src/';
saveFigures = 0;

% colors
clr_solo_single      = [245,0,0]/255;
clr_int_single       = [1, 99,153 ]/255;
clr_contint_single   = [25,110,37  ]/255;
clr_stiffconn_single = [166,97,26]/255;

%% load & extract data
% load performance data
load('../data/data_rmse_all.mat')

% participant 11, cont int
ydata_int_single_contint(:,11) = NaN;

% calculate final tracking error
% indices to select correct trials
idx_Ef_single1 = [76 78 80 82 84];
idx_Ef_single2 = [40 41 42 43 44];

% int and solo
Ef_solo_single  = nanmean(ydata_solo_single(idx_Ef_single1,:),1).';
Ef_int_single = nanmean(ydata_int_single(idx_Ef_single2,:),1).';
Ef_stiffconn_single = nanmean(ydata_stiffconn_single(idx_Ef_single1,:),1).'; % here's something wrong
Ef_contint_single = nanmean(ydata_int_single_contint(idx_Ef_single1,:),1).';

% extract E0
Es0_solo  = ydata_solo_single(22,:).';
Es0_int = ydata_int_single(12,:).';
Es0_stiffconn = ydata_stiffconn_single(22,:).';
Es0_contint = ydata_int_single_contint(13,:).';

% calculate partner's relative initial tracking error
% for every participant, set index of their partner
idx_partner = [2 1 4 3 6 5 8 7 10 9 12 11 14 13 16 15 18 17 20 19];

% ratio, in percentage
R_Es0_solo = (1-Es0_solo(idx_partner)./Es0_solo)*1e2;
R_Es0_int = (1-Es0_int(idx_partner)./Es0_int)*1e2;
R_Es0_stiffconn = (1-Es0_stiffconn(idx_partner)./Es0_stiffconn)*1e2;
R_Es0_contint = (1-Es0_contint(idx_partner)./Es0_contint)*1e2;

% improvement
imp_solo_single = Es0_solo-Ef_solo_single;
imp_int_single = Es0_int-Ef_int_single;
imp_stiffconn_single = Es0_stiffconn-Ef_stiffconn_single;
imp_contint_single = Es0_contint-Ef_contint_single;

%% plot Es0 and improvement
figure('color','w')
plot(R_Es0_solo,imp_solo_single*1e3,'o','markerfacecolor',clr_solo_single,'color',clr_solo_single); hold on;
plot(R_Es0_int,imp_int_single*1e3,'s','markerfacecolor',clr_int_single,'color',clr_int_single);
plot(R_Es0_stiffconn,imp_stiffconn_single*1e3,'v','markerfacecolor',clr_stiffconn_single,'color',clr_stiffconn_single);
plot(R_Es0_contint,imp_contint_single*1e3,'v','markerfacecolor',clr_contint_single,'color',clr_contint_single);
xlabel('Parner''s relative Es0'); ylabel('improvement')

%% learning rate
load('../data/data_improvement_rates.mat')

% slow improvement rate
lambda_slow_solo_single = fit_solo_single_ind_2exp.p(5,:).';            
lambda_slow_int_single = fit_int_single_ind_2exp.p(5,:).';              
lambda_slow_stiffconn_single = fit_stiffconn_single_ind_2exp.p(5,:).';  

% fast improvement rate
lambda_fast_solo_single = fit_solo_single_ind_2exp.p(3,:).';
lambda_fast_int_single = fit_int_single_ind_2exp.p(3,:).';
lambda_fast_stiffconn_single = fit_stiffconn_single_ind_2exp.p(3,:).';


% plot E0 versus lambda_slow
figure('color','w')
plot(R_Es0_solo,lambda_slow_solo_single,'o','markerfacecolor',clr_solo_single,'color',clr_solo_single); hold on;
plot(R_Es0_int,lambda_slow_int_single,'s','markerfacecolor',clr_int_single,'color',clr_int_single);
plot(R_Es0_stiffconn,lambda_slow_stiffconn_single,'v','markerfacecolor',clr_stiffconn_single,'color',clr_stiffconn_single);
xlabel('Parner''s relative Es0'); ylabel('\lambda_{slow}');

% plot E0 versus lambda_fast

figure('color','w')
plot(R_Es0_solo,lambda_fast_solo_single,'o','markerfacecolor',clr_solo_single,'color',clr_solo_single); hold on;
plot(R_Es0_int,lambda_fast_int_single,'s','markerfacecolor',clr_int_single,'color',clr_int_single);
plot(R_Es0_stiffconn,lambda_fast_stiffconn_single,'v','markerfacecolor',clr_stiffconn_single,'color',clr_stiffconn_single);
xlabel('Parner''s relative Es0'); ylabel('\lambda_{fast}');
ylim([0 6]);
