%% B_all_learning_curves
% Plot all learning curves, mean+SD and the individual learning curves
%
% Niek Beckers

clearvars -except alldata
close all; clc;

data = load('../data/data_rmse_all.mat');


plot_individual(data, 1, 'solo-intint'); 
% plot_individual(data, 2, 'contint'); 
% plot_individual(data, 3, 'stiffint');

function h = plot_individual(data, plotWhat, name)
%% Plot individual learning curves for all groups

switch plotWhat
    case 1
        x_single = data.xdata_int_single;
        x_conn = data.xdata_int_conn;
        y_single = data.ydata_int_single;
        y_conn = data.ydata_int_conn;
        
        x_solo = data.xdata_solo_single;
        y_solo = data.ydata_solo_single;

        clr_solo_single = [245,125,0]/255;
        clr_int_single = [  1, 99,153]/255;
        clr_int_conn = [ 85,161,202]/255;
    case 2      
        x_single = data.xdata_int_single_contint;
        x_conn = data.xdata_int_conn_contint;
        y_single = data.ydata_int_single_contint;
        y_conn = data.ydata_int_conn_contint;

        clr_int_single = [25,110,37]/255;
        clr_int_conn = [4,194,31]/255;
        
    case 3
        x_single = data.xdata_stiffconn_single;
        x_conn = data.xdata_stiffconn_conn;
        y_single = data.ydata_stiffconn_single;
        y_conn = data.ydata_stiffconn_conn;

        clr_int_single = [  166,97,26]/255;
        clr_int_conn = [ 223,194,125]/255;
end


figure('color','w')

if (plotWhat == 1)
    subplot(131)
    plot(x_solo, y_solo*1e3,'.-','color',clr_solo_single);
end
xlim([0 85]); ylim([0 90]);
xlabel('trial'); ylabel('E_s [mm]');

%% interaction group single
subplot(132)

if (plotWhat == 2)
    % plot participant 11 for the contint group with a different
    % colour (pair 6, partner 1)
    % block 1, trial 13 (Es0 trial) is plotted separately
    plot(x_single(13,11),y_single(13,11)*1e3,'.','color',0.3*[1 1 1]); hold on;
    y_single(13,11) = NaN;
    plot(x_single(:,11),y_single(:,11)*1e3,'.-','color',0.3*[1 1 1]); hold on;
    y_single(:,11) = NaN;
   
    % also plot trial 13 for the other participant's separately too
    plot(x_single(13,:), y_single(13,:)*1e3,'.','color',clr_int_single)
    y_single(13,:) = NaN;
end
% plot everything
plot(x_single,y_single*1e3,'.-','color',clr_int_single); hold on;

xlim([0 85]); ylim([0 80]);
xlabel('Trial'); ylabel('E_s [mm]');

%% interaction group conn
subplot(133)

if (plotWhat == 2)
    % participant 11 first
    plot(x_conn(:,11),y_conn(:,11)*1e3,'.-','color',0.3*[1 1 1]); hold on;
    y_conn(:,11) = NaN;
end
    
% plot everything
plot(x_conn,y_conn*1e3,'.-','color',clr_int_conn); hold on;

xlim([0 85]); ylim([0 80]);
xlabel('Trial'); ylabel('E_c [cm]');

% tikz_path = 'img/tikz-src/';
% matlab2tikz([tikz_path 'fig-s1-individual-error-curves-' name '.tex'],'externaldata',true,'dataPath',[tikz_path 'data-fig-s1-individual-error-curves-' name]);
end