%% figure_s2_improvement_groupmean
% plots figure s2, improvement based on group mean of the initial tracking
% error
% 
% Scientific Reports
% Niek Beckers, 2020

clearvars; close all; clc;

% colors and stuff
clr_solosingle      = [245,0,0]/255;
clr_intsingle       = [25, 86,179 ]/255;
clr_intconn         = [85,161,202 ]/255;
clr_intsingle_contint = [38,117,38  ]/255;
clr_intconn_contint   = [4,194,31 ]/255;
clr_intsingle_stiffconn = [102, 51, 0]/255;
clr_intconn_stiffconn   = [ 223,194,125]/255;
clr_gray = [0.8 0.8 0.8];

%% load and prepare data
load('../data/data_rmse_all.mat');

% subject 11 in the continuous interaction group is consistently very high
% tracking errors; we took him out.
ydata_int_single_contint(:,11) = NaN;

% extract data
ydata_int_single = ydata_int_single*1e3; % to mm
ydata_solo_single = ydata_solo_single*1e3; % to mm

% continuous interaction
ydata_contint_single = ydata_int_single_contint*1e3;
xdata_contint_single = repmat((1:84).',[1,20]);

% stiff connection group
ydata_stiffconn_single = ydata_stiffconn_single*1e3;

% indices for block 1
idx_solo_single_block1 = 1:21;
idx_stiffconn_single_block1 = 1:2:21;
idx_contint_single_block1 = 1:2:21;
idx_int_single_block1 = 1:11;

% indices for blocks 2-4
idx_solo_single_blocks234 = 22:84;
idx_stiffconn_single_blocks234 = [22:2:42 43:2:63 64:2:84];
idx_int_single_blocks234 = 12:44;
idx_contint_single_blocks234 = 73:84;

%% Calculate individual improvement
% Improvement is calculated with respect to the group's mean Es0.

% block 1
imp_solo_single_block1 = nanmean(ydata_solo_single(1,:)) - ydata_solo_single(idx_solo_single_block1,:);
imp_int_single_block1 = nanmean(ydata_int_single(1,:)) - ydata_int_single(idx_int_single_block1,:);
imp_stiffconn_single_block1 = nanmean(ydata_stiffconn_single(1,:)) - ydata_stiffconn_single(idx_stiffconn_single_block1,:);
imp_contint_single_block1 = nanmean(ydata_contint_single(1,:)) - ydata_contint_single(idx_contint_single_block1,:);

% blocks 2-4
imp_solo_single_blocks234 = nanmean(ydata_solo_single(idx_solo_single_blocks234(1),:)) - ydata_solo_single(idx_solo_single_blocks234,:);
imp_int_single_blocks234 = nanmean(ydata_int_single(idx_int_single_blocks234(1),:)) - ydata_int_single(idx_int_single_blocks234,:);
imp_stiffconn_single_blocks234 = nanmean(ydata_stiffconn_single(idx_stiffconn_single_blocks234(1),:)) - ydata_stiffconn_single(idx_stiffconn_single_blocks234,:);
imp_contint_single_blocks234 = nanmean(ydata_contint_single(13,:)) - ydata_contint_single(idx_contint_single_blocks234,:);



%% plot
figure('color','w','position',[0 50 850 380]);

% blocks 2-4
subplot(1,3,[1 2])
errorbar(xdata_solo_single(idx_solo_single_blocks234,1),nanmean(imp_solo_single_blocks234,2),nanstd(imp_solo_single_blocks234,[],2)/sqrt(20),'o-','color',clr_solosingle,'markerfacecolor',clr_solosingle); hold on;
errorbar(xdata_int_single(idx_int_single_blocks234,1),nanmean(imp_int_single_blocks234,2),nanstd(imp_int_single_blocks234,[],2)/sqrt(20),'d-','color',clr_intsingle,'markerfacecolor',clr_intsingle);
errorbar(xdata_stiffconn_single(idx_stiffconn_single_blocks234,1),nanmean(imp_stiffconn_single_blocks234,2),nanstd(imp_stiffconn_single_blocks234,[],2)/sqrt(20),'v-','color',clr_intsingle_stiffconn,'markerfacecolor',clr_intsingle_stiffconn);
errorbar(xdata_contint_single(idx_contint_single_blocks234,1),nanmean(imp_contint_single_blocks234,2),nanstd(imp_contint_single_blocks234,[],2)/sqrt(20),'^-','color',clr_intsingle_contint,'markerfacecolor',clr_intsingle_contint);

xlabel('Trial'); ylabel('Improvement using group-mean of E_{s,0}');
ylim([-5 50])

% bar graph
subplot(1,3,3)

x = [1 2 3 4];
y = [imp_solo_single_blocks234(end,:).' imp_int_single_blocks234(end,:).' imp_stiffconn_single_blocks234(end,:).' imp_contint_single_blocks234(end,:).'];

hbp = bar(x,nanmean(y,1)); hold on
hbp.FaceColor = 'flat';
hbp.CData(1,:) = clr_solosingle;
hbp.CData(2,:) = clr_intsingle;
hbp.CData(3,:) = clr_intsingle_stiffconn;
hbp.CData(4,:) = clr_intsingle_contint;

plot(1*ones(size(imp_solo_single_blocks234(end,:))), y(:,1),'marker','s','linestyle','none','markerfacecolor',clr_solosingle);
plot(2*ones(size(imp_int_single_blocks234(end,:))), y(:,2), 'o','linestyle','none','markerfacecolor',clr_intsingle,'markeredgecolor','w');
plot(3*ones(size(imp_stiffconn_single_blocks234(end,:))), y(:,3), '^','linestyle','none','markerfacecolor',clr_intsingle_stiffconn,'markeredgecolor','w');
plot(4*ones(size(imp_contint_single_blocks234(end,:))), y(:,4), 'v','linestyle','none','markerfacecolor',clr_intsingle_contint,'markeredgecolor','w');

errorbar(x,nanmean(y,1),nanstd(y,[],1)/sqrt(20),'linestyle','none','color','k')

ylim([-5 50])

% matlab2tikz([tikz_path 'fig-suppinfo-improvement-groupmean.tex'],'externaldata',true,'dataPath',[tikz_path 'data-fig-suppinfo-improvement-groupmean']);